# Generated by Django 4.2.6 on 2024-01-14 14:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscarbot', '0005_constructor'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='state_information',
            field=models.TextField(blank=True, null=True),
        ),
    ]
